@@ -20,7 +20,7 @@ from pi_touch_gui._utilities import backlog_error
 from pi_touch_gui._widget_bases import IWidget, IWidgetInterface
 from pi_touch_gui.colors import BLACK
 from pi_touch_gui.multitouch.raspberrypi_ts import Touchscreen, TS_RELEASE
-from widget_buttons import Button
+from pi_touch_gui.widget_buttons import Button
 
 LOG = logging.getLogger(__name__)
 
